@@ -2031,6 +2031,11 @@ void table_result_destroy(table_result_t *value)
     {
         free(value->durations);
     }
+
+    if(value->distances != NULL)
+    {
+        free(value->distances);
+    }
     
     if(value->sources != NULL)
     {
