@@ -635,6 +635,11 @@ impl GeneralOptions {
         }
     }
 
+    pub fn skip_waypoints(&mut self, val: bool) -> &mut GeneralOptions {
+        self.skip_waypoints = val;
+        self
+    }
+
     pub fn radiuses(&mut self, val: &Option<Vec<Option<f64>>>) -> &mut GeneralOptions {
         self.radiuses = val.clone();
         self
